@@ -144,7 +144,9 @@ Member_recovery_method Add_replica_instance::validate_instance_recovery() {
       m_options.clone_options.recovery_method.value_or(
           Member_recovery_method::AUTO),
       m_cluster_impl->get_gtid_set_is_complete(),
-      current_shell_options()->get().wizards);
+      current_shell_options()->get().wizards,
+      m_cluster_impl->check_clone_availablity(*m_donor_instance,
+                                              *m_target_instance));
 }
 
 void Add_replica_instance::validate_source_list() {
@@ -187,6 +189,9 @@ std::shared_ptr<Instance> Add_replica_instance::get_default_source_instance() {
   // ONLINE
   std::shared_ptr<Instance> main_source;
 
+  // Set to track unique "host:port" strings
+  std::set<std::string> unique_sources;
+
   for (const auto &source :
        m_options.replication_sources_option.replication_sources) {
     auto source_instance = get_source_instance(source.to_string());
@@ -196,6 +201,7 @@ std::shared_ptr<Instance> Add_replica_instance::get_default_source_instance() {
     //   a) The instance belongs to the MD
     //   b) The instance is not a Read-Replica
     //   c) The instance is ONLINE
+    //   d) The instance is duplicated in the list
 
     try {
       // Check if the address is in the Metadata
@@ -242,6 +248,18 @@ std::shared_ptr<Instance> Add_replica_instance::get_default_source_instance() {
           SHERR_DBA_READ_REPLICA_INVALID_SOURCE_LIST_NOT_ONLINE);
     }
 
+    // Check if the instance is duplicated in the list
+    if (!unique_sources.insert(source.to_string()).second) {
+      mysqlsh::current_console()->print_error(shcore::str_format(
+          "Found multiple entries for '%s': Each entry in the "
+          "'replicationSources' list must be unique. Please remove any "
+          "duplicates before retrying the command.",
+          source.to_string().c_str()));
+      throw shcore::Exception(
+          "Duplicate entries detected in 'replicationSources'",
+          SHERR_DBA_READ_REPLICA_INVALID_SOURCE_LIST_DUPLICATE_ENTRY);
+    }
+
     // The main source must be the first member of the 'replicationSources'
     if (!main_source) {
       main_source = std::move(source_instance);
@@ -336,8 +354,15 @@ void Add_replica_instance::do_run() {
     }
 
     // Check if the donor is valid
-    m_cluster_impl->ensure_compatible_clone_donor(*m_donor_instance,
-                                                  *m_target_instance);
+    {
+      m_cluster_impl->ensure_donor_is_valid(*m_donor_instance);
+
+      if (*m_options.clone_options.recovery_method ==
+          Member_recovery_method::CLONE) {
+        m_cluster_impl->check_compatible_clone_donor(*m_donor_instance,
+                                                     *m_target_instance);
+      }
+    }
 
     console->print_info("* Checking transaction state of the instance...");
     m_options.clone_options.recovery_method = validate_instance_recovery();
