@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2014, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2014, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -23,29 +25,22 @@
 
 #include "modules/mod_mysql_session.h"
 
-#include <set>
 #include <string>
-#include <thread>
 #include <vector>
 
 #include "modules/mod_mysql_resultset.h"
-#include "modules/mod_utils.h"
 #include "modules/mysqlxtest_utils.h"
 #include "mysqlshdk/include/scripting/obj_date.h"
 #include "mysqlshdk/include/scripting/type_info/custom.h"
 #include "mysqlshdk/include/scripting/type_info/generic.h"
+#include "mysqlshdk/include/shellcore/scoped_contexts.h"
 #include "mysqlshdk/libs/ssh/ssh_manager.h"
-#include "scripting/lang_base.h"
-#include "scripting/object_factory.h"
-#include "scripting/proxy_object.h"
-#include "shellcore/shell_core.h"
 #include "shellcore/shell_notifications.h"
 #include "shellcore/utils_help.h"
 #include "utils/utils_general.h"
 #include "utils/utils_path.h"
 #include "utils/utils_sqlstring.h"
 
-using namespace std::placeholders;
 using namespace mysqlsh;
 using namespace mysqlsh::mysql;
 using namespace shcore;
@@ -90,7 +85,6 @@ void ClassicSession::init() {
 
   expose("close", &ClassicSession::close);
   expose("runSql", &ClassicSession::run_sql, "query", "?args");
-  expose("query", &ClassicSession::query, "query", "?args");
   expose("isOpen", &ClassicSession::is_open);
   expose("startTransaction", &ClassicSession::_start_transaction);
   expose("commit", &ClassicSession::_commit);
@@ -197,6 +191,8 @@ std::vector<mysqlshdk::db::Query_attribute> ClassicSession::query_attributes()
             // Only the date object is supported
             if (auto date = att.as_object<Date>(); date) {
               MYSQL_TIME time;
+              std::memset(&time, 0, sizeof(time));
+
               time.year = date->get_year();
               time.month = date->get_month();
               time.day = date->get_day();
@@ -276,40 +272,6 @@ std::shared_ptr<ClassicResult> ClassicSession::run_sql(
   return ret_val;
 }
 
-REGISTER_HELP_FUNCTION(query, ClassicSession);
-REGISTER_HELP_FUNCTION_TEXT(CLASSICSESSION_QUERY, R"*(
-Executes a query and returns the corresponding ClassicResult object.
-
-@param query the SQL query string to execute, with optional ? placeholders.
-@param args Optional list of literals to use when replacing ? placeholders in
-the query string.
-
-@returns A ClassicResult object.
-
-@attention This function will be removed in a future release, use the
-<b><<<runSql>>></b> function instead.
-
-@throw An exception is thrown if an error occurs on the SQL execution.
-)*");
-/**
- * $(CLASSICSESSION_QUERY_BRIEF)
- *
- * $(CLASSICSESSION_QUERY)
- */
-#if DOXYGEN_JS
-ClassicResult ClassicSession::query(String query, Array args = []) {}
-#elif DOXYGEN_PY
-ClassicResult ClassicSession::query(str query, list args = []) {}
-#endif
-std::shared_ptr<ClassicResult> ClassicSession::query(
-    const std::string &query, const shcore::Array_t &args) {
-  auto console = mysqlsh::current_console();
-  console->print_warning("'query' is deprecated, use " +
-                         get_function_name("runSql") + " instead.");
-
-  return run_sql(query, args);
-}
-
 std::shared_ptr<mysqlshdk::db::IResult> ClassicSession::execute_sql(
     const std::string &query, const shcore::Array_t &args,
     const std::vector<mysqlshdk::db::Query_attribute> &query_attributes) {
