@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2014, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2014, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -642,7 +644,7 @@ void dump_json_row(shcore::JSON_dumper *dumper,
         dumper->append_string(encoded);
       } else {
         auto data = row->get_as_string(col_index);
-        dumper->append_string(data.c_str(), data.length());
+        dumper->append_string(data);
       }
     } else if (type == mysqlshdk::db::Type::Integer) {
       dumper->append_int64(row->get_int(col_index));
@@ -850,14 +852,8 @@ std::string Resultset_dumper_base::format_json(const std::string &item_label,
   dumper.append_string("executionTime");
   dumper.append_string(
       mysqlshdk::utils::format_seconds(m_result->get_execution_time()));
-  if (!is_doc_result) {
-    dumper.append_string("affectedRowCount");
-    dumper.append_uint64(m_result->get_affected_row_count());
-  }
   dumper.append_string("affectedItemsCount");
   dumper.append_uint64(m_result->get_affected_row_count());
-  dumper.append_string("warningCount");
-  dumper.append_int64(m_result->get_warning_count());
   dumper.append_string("warningsCount");
   dumper.append_uint64(m_result->get_warning_count());
   dumper.append_string("warnings");
