@@ -224,6 +224,7 @@ class Shell_api_tester : public Helper_tester {
     SCOPED_TRACE("Shell_api_tester::select_helper()");
 
     m_wrapper.reset(new Shell_test_wrapper{false});
+    m_wrapper->execute("\\js");
 
     execute("shell.options[\"credentialStore.helper\"] = " +
             shcore::quote_string(name, '\"') + ";");
@@ -245,7 +246,7 @@ class Shell_api_tester : public Helper_tester {
 
     EXPECT_EQ(Secret_type::PASSWORD, type);
 
-#ifdef HAVE_JS
+#ifdef HAVE_V8
     execute("shell.storeCredential(" + shcore::quote_string(url, '\"') + ", " +
             shcore::quote_string(secret, '\"') + ");");
 #else
@@ -265,7 +266,7 @@ class Shell_api_tester : public Helper_tester {
 
     EXPECT_EQ(Secret_type::PASSWORD, type);
 
-#ifdef HAVE_JS
+#ifdef HAVE_V8
     execute("shell.deleteCredential(" + shcore::quote_string(url, '\"') + ");");
 #else
     execute("shell.delete_credential(" + shcore::quote_string(url, '\"') +
@@ -278,7 +279,7 @@ class Shell_api_tester : public Helper_tester {
   bool list(std::vector<Secret_spec> *specs) override {
     SCOPED_TRACE("Shell_api_tester::list()");
 
-#ifdef HAVE_JS
+#ifdef HAVE_V8
     execute("print(shell.listCredentials());");
 #else
     execute("print(shell.list_credentials());");
@@ -319,7 +320,7 @@ class Shell_api_tester : public Helper_tester {
   void expect_delete_all_credentials() {
     SCOPED_TRACE("Shell_api_tester::expect_delete_all_credentials()");
 
-#ifdef HAVE_JS
+#ifdef HAVE_V8
     execute("shell.deleteAllCredentials();");
 #else
     execute("shell.delete_all_credentials();");
