@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2017, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2017, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -34,6 +36,8 @@
 
 class Mysqlsh_misc : public tests::Command_line_test {};
 
+#ifdef USE_MYSQLX_FULL_PROTO
+
 TEST_F(Mysqlsh_misc, trace_proto) {
   execute({_mysqlsh, _uri.c_str(), "--trace-proto", "--sql", "-e", "select 1",
            nullptr});
@@ -75,6 +79,8 @@ TEST_F(Mysqlsh_misc, trace_proto) {
   }
 }
 
+#endif
+
 TEST_F(Mysqlsh_misc, load_builtin_modules) {
 // Regression test for Bug #26174373
 // Built-in modules should auto-load in non-interactive sessions too
@@ -222,11 +228,12 @@ TEST_F(Mysqlsh_misc, autodetect_script_type) {
   wipe_out();
 
 #ifdef HAVE_V8
-  // will exec using JS - OK
+  // will exec using SQL (default) - ERROR
   execute({_mysqlsh, "-f", "js.foo", nullptr});
-  MY_EXPECT_CMD_OUTPUT_CONTAINS("JS works!");
+  MY_EXPECT_CMD_OUTPUT_CONTAINS("Not connected");
   wipe_out();
 
+  // will exec using JS - OK
   execute({_mysqlsh, "--js", "-f", "js.foo", nullptr});
   MY_EXPECT_CMD_OUTPUT_CONTAINS("JS works!");
   wipe_out();
