@@ -10,7 +10,6 @@ Usage: mysqlsh [OPTIONS] [URI]
        mysqlsh [OPTIONS] [URI] --cluster|--replicaset
        mysqlsh [OPTIONS] [URI] -- <object> <method> [<method-args>...]
        mysqlsh [OPTIONS] [URI] --dba enableXProtocol
-       mysqlsh [OPTIONS] [URI] --import {<file>|-} [<collection>|<table> <column>]
 
   -?, --help                       Display this help and exit.
   --                               Triggers API Command Line integration, which
@@ -86,11 +85,6 @@ Usage: mysqlsh [OPTIONS] [URI]
   --zstd-compression-level=<int>   client/server protocol. Supported by X
                                    protocol and zstd compression in classic
                                    protocol.
-  --import <file> <collection>     Import JSON documents from file to
-  --import <file> <table> <col>    collection or table in MySQL Server. Set
-                                   file to - if you want to read the data from
-                                   stdin. Requires a default schema on the
-                                   connection options.
   -D, --schema=<name>              Schema to use.
   --database=<name>                Same as --schema.
   --register-factor=<name>         Specifies authentication factor, for which
@@ -100,8 +94,6 @@ Usage: mysqlsh [OPTIONS] [URI]
                                    to be used for signing challenge. If not
                                    enabled, challenge is signed by all
                                    credentials for given relying party.
-  --recreate-schema                Drop and recreate the specified schema.
-                                   Schema will be deleted if it exists!
   --mx, --mysqlx                   Uses connection data to create an X protocol
                                    session.
   --mc, --mysql                    Uses connection data to create a classic
@@ -255,6 +247,7 @@ Usage: mysqlsh [OPTIONS] [URI]
                                    SHA256_MEMORY.
   --dba=enableXProtocol            Enable the X protocol in the target server.
                                    Requires a connection using classic session.
+                                   Deprecated.
   --quiet-start[={1|2}]            Avoids printing information when the shell
                                    is started. A value of 1 will prevent
                                    printing the shell version information. A
