@@ -283,18 +283,14 @@ function debugAuthPlugins() {
 
 
 function getAuthServerConfig(context) {
-  if (!isAuthMethodSupported(context)) {
-    return {};
-  }
-
   const ext = __os_type == "windows" ? "dll" : "so";
 
   if (context == 'LDAP_SIMPLE') {
     var server_conf = {
       "plugin-load-add": `authentication_ldap_simple.${ext}`,
-      "authentication_ldap_simple_server_host": `${LDAP_SIMPLE_SERVER_HOST}`,
-      "authentication_ldap_simple_server_port": parseInt(`${LDAP_SIMPLE_SERVER_PORT}`),
-      "authentication_ldap_simple_bind_base_dn": `${LDAP_SIMPLE_BIND_BASE_DN}`
+      "loose-authentication_ldap_simple_server_host": `${LDAP_SIMPLE_SERVER_HOST}`,
+      "loose-authentication_ldap_simple_server_port": parseInt(`${LDAP_SIMPLE_SERVER_PORT}`),
+      "loose-authentication_ldap_simple_bind_base_dn": `${LDAP_SIMPLE_BIND_BASE_DN}`
     };
 
     if (__os_type == 'windows') {
@@ -306,25 +302,25 @@ function getAuthServerConfig(context) {
   } else if (context == 'LDAP_SASL') {
     return {
       "plugin-load-add": `authentication_ldap_sasl.${ext}`,
-      "authentication_ldap_sasl_server_host": `${LDAP_SASL_SERVER_HOST}`,
-      "authentication_ldap_sasl_server_port": parseInt(`${LDAP_SASL_SERVER_PORT}`),
-      "authentication_ldap_sasl_group_search_filter": `${LDAP_SASL_GROUP_SEARCH_FILTER}`,
-      "authentication_ldap_sasl_bind_base_dn": `${LDAP_SASL_BIND_BASE_DN}`,
-      "authentication_ldap_sasl_log_status": 5,
+      "loose-authentication_ldap_sasl_server_host": `${LDAP_SASL_SERVER_HOST}`,
+      "loose-authentication_ldap_sasl_server_port": parseInt(`${LDAP_SASL_SERVER_PORT}`),
+      "loose-authentication_ldap_sasl_group_search_filter": `${LDAP_SASL_GROUP_SEARCH_FILTER}`,
+      "loose-authentication_ldap_sasl_bind_base_dn": `${LDAP_SASL_BIND_BASE_DN}`,
+      "loose-authentication_ldap_sasl_log_status": 5,
       "log_error_verbosity": 3
     };
   } else if (context == 'LDAP_KERBEROS') {
     return {
       "plugin-load-add": `authentication_ldap_sasl.${ext}`,
-      "authentication_ldap_sasl_server_host": `${LDAP_KERBEROS_SERVER_HOST}`,
-      "authentication_ldap_sasl_server_port": parseInt(`${LDAP_KERBEROS_SERVER_PORT}`),
-      "authentication_ldap_sasl_bind_base_dn": `${LDAP_KERBEROS_BIND_BASE_DN}`,
-      "authentication_ldap_sasl_user_search_attr": `${LDAP_KERBEROS_USER_SEARCH_ATTR}`,
-      "authentication_ldap_sasl_bind_root_dn": `${LDAP_KERBEROS_BIND_ROOT_DN}`,
-      "authentication_ldap_sasl_bind_root_pwd": `${LDAP_KERBEROS_BIND_ROOT_PWD}`,
-      "authentication_ldap_sasl_group_search_filter": `${LDAP_KERBEROS_GROUP_SEARCH_FILTER}`,
-      "authentication_ldap_sasl_auth_method_name": 'GSSAPI',
-      "authentication_ldap_sasl_log_status": 5,
+      "loose-authentication_ldap_sasl_server_host": `${LDAP_KERBEROS_SERVER_HOST}`,
+      "loose-authentication_ldap_sasl_server_port": parseInt(`${LDAP_KERBEROS_SERVER_PORT}`),
+      "loose-authentication_ldap_sasl_bind_base_dn": `${LDAP_KERBEROS_BIND_BASE_DN}`,
+      "loose-authentication_ldap_sasl_user_search_attr": `${LDAP_KERBEROS_USER_SEARCH_ATTR}`,
+      "loose-authentication_ldap_sasl_bind_root_dn": `${LDAP_KERBEROS_BIND_ROOT_DN}`,
+      "loose-authentication_ldap_sasl_bind_root_pwd": `${LDAP_KERBEROS_BIND_ROOT_PWD}`,
+      "loose-authentication_ldap_sasl_group_search_filter": `${LDAP_KERBEROS_GROUP_SEARCH_FILTER}`,
+      "loose-authentication_ldap_sasl_auth_method_name": 'GSSAPI',
+      "loose-authentication_ldap_sasl_log_status": 5,
       "log_error_verbosity": 3,
       "net_read_timeout": 360,
       "connect_timeout": 360
@@ -335,8 +331,8 @@ function getAuthServerConfig(context) {
 
     return {
       "plugin-load-add": `authentication_kerberos.${ext}`,
-      "authentication_kerberos_service_principal": `mysql_service/kerberos_auth_host@${LDAP_KERBEROS_DOMAIN}`,
-      "authentication_kerberos_service_key_tab": keytab_file,
+      "loose-authentication_kerberos_service_principal": `mysql_service/kerberos_auth_host@${LDAP_KERBEROS_DOMAIN}`,
+      "loose-authentication_kerberos_service_key_tab": keytab_file,
       "net_read_timeout": 360,
       "connect_timeout": 360,
       "log_error_verbosity": 3
@@ -347,7 +343,7 @@ function getAuthServerConfig(context) {
     };
   } else if (context == 'WEBAUTHN') {
     return {
-      "authentication-webauthn-rp-id": "mysql.com",
+      "loose-authentication-webauthn-rp-id": "mysql.com",
       "plugin-load-add": `authentication_webauthn.${ext}`
     };
   }
@@ -356,7 +352,7 @@ function getAuthServerConfig(context) {
 }
 
 
-function isAuthMethodSupported(context) {
+function isAuthMethodSupported(context, uri=__mysqluripwd) {
   if (['LDAP_SIMPLE', 'LDAP_SASL', 'LDAP_KERBEROS', 'KERBEROS', 'FIDO', 'WEBAUTHN', 'OCI_AUTH'].indexOf(context) == -1) {
     return false;
   }
@@ -381,14 +377,14 @@ function isAuthMethodSupported(context) {
   }
 
   var plugin_supported = true;
-  const s = shell.openSession(__mysqluripwd);
+  const s = shell.openSession(uri);
 
   try {
     ensure_plugin_enabled(plugin, s);
   } catch (error) {
     plugin_supported = error.code == PLUGIN_ALREADY_EXISTS;
     if (!plugin_supported) {
-      print(`Unable to get ${plugin} installed: Error ${error.code}: ${error.message}`)
+      shell.log('warning', `Unable to get ${plugin} installed: Error ${error.code}: ${error.message}`)
     }
   }
 
@@ -400,12 +396,6 @@ function isAuthMethodSupported(context) {
         plugin_supported = false;
       }
     }
-
-    try {
-      ensure_plugin_disabled(plugin, s);
-    } catch (error) {
-      // ignore any errors
-    }
   }
 
   s.close();
@@ -664,9 +654,9 @@ function disable_auto_rejoin(session, port) {
 
   if (__version_num > 80011) {
     try {
-      session.runSql("RESET PERSIST group_replication_start_on_boot");
+      session.runSql("SET PERSIST group_replication_start_on_boot=OFF");
     } catch (e) {
-      if (e["code"] != 3615) {
+      if (e["code"] != 3615 && e["code"] != 1193) {
         throw e;
       }
     }
@@ -776,7 +766,7 @@ var SANDBOX_PORTS = [__mysql_sandbox_port1, __mysql_sandbox_port2, __mysql_sandb
 var SANDBOX_LOCAL_URIS = [__sandbox_uri1, __sandbox_uri2, __sandbox_uri3];
 var SANDBOX_URIS = [__hostname_uri1, __hostname_uri2, __hostname_uri3];
 
-var s = mysql.getSession(__mysqluripwd+"?ssl-mode=disabled");
+var s = mysql.getSession(__mysqluripwd+"?ssl-mode=preferred");
 var r = s.runSql("SELECT @@hostname, @@report_host").fetchOne();
 var __mysql_hostname = r[0];
 var __mysql_report_host = r[1];
@@ -953,6 +943,15 @@ function EXPECT_GT(value1, value2, note) {
   }
 }
 
+function EXPECT_GE(value1, value2, note) {
+  if (note === undefined)
+    note = "";
+  if (value1 < value2) {
+    var context = "<b>Context:</b> " + __test_context + "\n<red>EXPECT_GE failed:</red> " + note + "\n\t"+repr(value1)+" expected to be >= "+repr(value2)+" but isn't.";
+    testutil.fail(context);
+  }
+}
+
 function EXPECT_LT(value1, value2, note) {
   if (note === undefined)
     note = "";
@@ -962,6 +961,15 @@ function EXPECT_LT(value1, value2, note) {
   }
 }
 
+function EXPECT_LE(value1, value2, note) {
+  if (note === undefined)
+    note = "";
+  if (value1 > value2) {
+    var context = "<b>Context:</b> " + __test_context + "\n<red>EXPECT_LE failed:</red> " + note + "\n\t"+repr(value1)+" expected to be <= "+repr(value2)+" but isn't.";
+    testutil.fail(context);
+  }
+}
+
 function EXPECT_JSON_EQ(expected, actual, note) {
 
   function compare_values(expected, actual, path) {
@@ -1188,8 +1196,8 @@ function EXPECT_OUTPUT_EMPTY() {
 
 function EXPECT_STDOUT_CONTAINS(text) {
   var out = testutil.fetchCapturedStdout(false);
-  var err = testutil.fetchCapturedStderr(false);
   if (out.indexOf(text) < 0) {
+    var err = testutil.fetchCapturedStderr(false);
     var context = "<b>Context:</b> " + __test_context + "\n<red>Missing output:</red> " + text + "\n<yellow>Actual stdout:</yellow> " + out + "\n<yellow>Actual stderr:</yellow> " + err;
     testutil.fail(context);
   }
@@ -1197,7 +1205,6 @@ function EXPECT_STDOUT_CONTAINS(text) {
 
 function EXPECT_STDOUT_CONTAINS_ONE_OF(text) {
     var out = testutil.fetchCapturedStdout(false);
-    var err = testutil.fetchCapturedStderr(false);
     var found = false;
     for (i in text) {
         if (out.indexOf(text[i])>= 0) {
@@ -1206,6 +1213,7 @@ function EXPECT_STDOUT_CONTAINS_ONE_OF(text) {
         }
     }
     if (!found) {
+      var err = testutil.fetchCapturedStderr(false);
       var context = "<b>Context:</b> " + __test_context + "\n<red>Missing STDOUT output:</red>\n";
       for (i in text) {
           context += text[i] + "\n";
@@ -1216,7 +1224,6 @@ function EXPECT_STDOUT_CONTAINS_ONE_OF(text) {
 }
 
 function EXPECT_STDERR_CONTAINS_ONE_OF(text) {
-    var out = testutil.fetchCapturedStdout(false);
     var err = testutil.fetchCapturedStderr(false);
     var found = false;
     for (i in text) {
@@ -1226,6 +1233,7 @@ function EXPECT_STDERR_CONTAINS_ONE_OF(text) {
         }
     }
     if (!found) {
+      var out = testutil.fetchCapturedStdout(false);
       var context = "<b>Context:</b> " + __test_context + "\n<red>Missing STDERR output:</red>\n";
       for (i in text) {
           context += text[i] + "\n";
@@ -1236,9 +1244,9 @@ function EXPECT_STDERR_CONTAINS_ONE_OF(text) {
 }
 
 function EXPECT_STDERR_CONTAINS(text) {
-  var out = testutil.fetchCapturedStdout(false);
   var err = testutil.fetchCapturedStderr(false);
   if (err.indexOf(text) < 0) {
+    var out = testutil.fetchCapturedStdout(false);
     var context = "<b>Context:</b> " + __test_context + "\n<red>Missing error output:</red> " + text + "\n<yellow>Actual stdout:</yellow> " + out + "\n<yellow>Actual stderr:</yellow> " + err;
     testutil.fail(context);
   }
@@ -1471,23 +1479,23 @@ function EXPECT_OUTPUT_CONTAINS_MULTILINE(t) {
 
 function EXPECT_STDOUT_CONTAINS_MULTILINE(t) {
   const out = __split_trim_join(testutil.fetchCapturedStdout(false));
-  const err = __split_trim_join(testutil.fetchCapturedStderr(false));
   const text = __split_trim_join(t);
   const out_result = __check_multiline_expect(text.array, out.array);
 
   if (!out_result.matches) {
+    const err = __split_trim_join(testutil.fetchCapturedStderr(false));
     const context = "<b>Context:</b> " + __test_context + "\n<red>Missing output:</red> " + text.str + "\n<yellow>Actual stdout:</yellow> " + out.str + "\n<yellow>Actual stderr:</yellow> " + err.str + "\n<yellow>Diff with stdout:</yellow>\n" + out_result.diff;
     testutil.fail(context);
   }
 }
 
 function EXPECT_STDERR_CONTAINS_MULTILINE(t) {
-  const out = __split_trim_join(testutil.fetchCapturedStdout(false));
   const err = __split_trim_join(testutil.fetchCapturedStderr(false));
   const text = __split_trim_join(t);
   const err_result = __check_multiline_expect(text.array, err.array);
 
   if (!err_result.matches) {
+    const out = __split_trim_join(testutil.fetchCapturedStdout(false));
     const context = "<b>Context:</b> " + __test_context + "\n<red>Missing output:</red> " + text.str + "\n<yellow>Actual stdout:</yellow> " + out.str + "\n<yellow>Actual stderr:</yellow> " + err.str + "\n<yellow>Diff with stderr:</yellow>\n" + err_result.diff;
     testutil.fail(context);
   }
@@ -1504,17 +1512,17 @@ function EXPECT_OUTPUT_MATCHES(re) {
 
 function EXPECT_STDOUT_MATCHES(re) {
   var out = testutil.fetchCapturedStdout(false);
-  var err = testutil.fetchCapturedStderr(false);
   if (!re.test(out)) {
+    var err = testutil.fetchCapturedStderr(false);
     var context = "<b>Context:</b> " + __test_context + "\n<red>Missing match for:</red> " + re.source + "\n<yellow>Actual stdout:</yellow> " + out + "\n<yellow>Actual stderr:</yellow> " + err;
     testutil.fail(context);
   }
 }
 
 function EXPECT_STDERR_MATCHES(re) {
-  var out = testutil.fetchCapturedStdout(false);
   var err = testutil.fetchCapturedStderr(false);
   if (!re.test(err)) {
+    var out = testutil.fetchCapturedStdout(false);
     var context = "<b>Context:</b> " + __test_context + "\n<red>Missing match for:</red> " + re.source + "\n<yellow>Actual stdout:</yellow> " + out + "\n<yellow>Actual stderr:</yellow> " + err;
     testutil.fail(context);
   }
@@ -1592,17 +1600,17 @@ function EXPECT_OUTPUT_NOT_CONTAINS(text) {
 
 function EXPECT_STDOUT_NOT_CONTAINS(text) {
   var out = testutil.fetchCapturedStdout(false);
-  var err = testutil.fetchCapturedStderr(false);
   if (out.indexOf(text) >= 0) {
+    var err = testutil.fetchCapturedStderr(false);
     var context = "<b>Context:</b> " + __test_context + "\n<red>Unexpected output:</red> " + text + "\n<yellow>Actual stdout:</yellow> " + out + "\n<yellow>Actual stderr:</yellow> " + err;
     testutil.fail(context);
   }
 }
 
 function EXPECT_STDERR_NOT_CONTAINS(text) {
-  var out = testutil.fetchCapturedStdout(false);
   var err = testutil.fetchCapturedStderr(false);
   if (err.indexOf(text) >= 0) {
+    var out = testutil.fetchCapturedStdout(false);
     var context = "<b>Context:</b> " + __test_context + "\n<red>Unexpected output:</red> " + text + "\n<yellow>Actual stdout:</yellow> " + out + "\n<yellow>Actual stderr:</yellow> " + err;
     testutil.fail(context);
   }
@@ -1710,7 +1718,7 @@ function ClusterScenario(ports, create_cluster_options, sandboxConfiguration) {
       testutil.waitMemberState(ports[i], "ONLINE");
 
       if (testutil.versionCheck(__version, "<", "8.0.0")) {
-        dba.configureLocalInstance(uri, {mycnfPath: testutil.getSandboxConfPath(ports[i])});
+        dba.configureInstance(uri, {mycnfPath: testutil.getSandboxConfPath(ports[i])});
       }
     }
   }
@@ -2047,15 +2055,24 @@ function get_replica_keyword(version) {
   return "REPLICA";
 }
 
-function get_replication_source_keyword(version) {
-  if (version === undefined)
-    version = __version_num;
+var replication_source_keywords = {
+  "REPLICATION SOURCE": "MASTER",
+  "GET_SOURCE_PUBLIC_KEY": "GET_MASTER_PUBLIC_KEY",
+  "SOURCE_USER": "MASTER_USER",
+  "SOURCE_PASSWORD": "MASTER_PASSWORD",
+  "REPLICA": "SLAVE"
+};
 
-  if (version < 80022) {
-    return "MASTER";
+function get_replication_source_keyword(version=__version_num, keyword="REPLICATION SOURCE") {
+  if (!(keyword in replication_source_keywords)) {
+    throw `Unkwnown replication source keyword: ${keyword}`
   }
 
-  return "REPLICATION SOURCE";
+  if (version < 80022) {
+    return replication_source_keywords[keyword];
+  }
+
+  return keyword;
 }
 
 function get_replication_option_keyword(version) {
