@@ -31,10 +31,8 @@
 #include <sys/stat.h>
 #endif
 #include "ext/linenoise-ng/include/linenoise.h"
-#include "modules/mod_shell.h"
 #include "modules/mod_shell_options.h"
 #include "mysqlshdk/libs/utils/utils_file.h"
-#include "mysqlshdk/libs/utils/utils_general.h"
 #include "mysqlshdk/libs/utils/utils_string.h"
 #include "src/mysqlsh/cmdline_shell.h"
 #include "unittest/test_utils.h"
@@ -43,7 +41,7 @@ namespace mysqlsh {
 
 class Shell_history : public ::testing::Test {
  protected:
-#ifdef HAVE_JS
+#ifdef HAVE_V8
   const std::string to_scripting = "\\js";
 #else
   const std::string to_scripting = "\\py";
@@ -120,15 +118,17 @@ TEST_F(Shell_history, check_password_history_linenoise) {
       std::make_shared<Shell_options>(2, args, _options_file));
   shell._history.set_limit(100);
 
-  auto coptions = shcore::get_connection_options("root@localhost");
+  auto coptions = mysqlshdk::db::Connection_options("root@localhost");
   coptions.set_scheme("mysql");
   coptions.set_password("");
   coptions.set_port(atoi(getenv("MYSQL_PORT")));
-  shell.connect(coptions, false);
+  shell.connect(coptions);
 
   EXPECT_EQ("*IDENTIFIED*:*PASSWORD*",
             shell.get_options()->get("history.sql.ignorePattern").descr());
 
+  // \js command should be filtered according to SQL mode rules
+  shell.process_line("\\js");
   EXPECT_EQ(0, linenoiseHistorySize());
 
   // \sql command should be filtered according to SQL mode rules
@@ -210,7 +210,7 @@ TEST_F(Shell_history, check_password_history_linenoise) {
   EXPECT_EQ(3, linenoiseHistorySize());
   EXPECT_STREQ("top;", linenoiseHistoryLine(2));
 
-#ifdef HAVE_JS
+#ifdef HAVE_V8
   std::string print_stmt = "println('secret');";
 #else
   std::string print_stmt = "print('secret')";
@@ -222,7 +222,7 @@ TEST_F(Shell_history, check_password_history_linenoise) {
   EXPECT_EQ(1, linenoiseHistorySize());
   EXPECT_STREQ(print_stmt.c_str(), linenoiseHistoryLine(0));
 
-#ifdef HAVE_JS
+#ifdef HAVE_V8
   shell.process_line("\\py");
   shell.process_line("print('secret')");
   EXPECT_EQ(1, linenoiseHistorySize());
@@ -347,6 +347,9 @@ TEST_F(Shell_history, check_password_history_linenoise) {
   EXPECT_EQ(5, linenoiseHistorySize());
   shell.process_line("a b c;");
   EXPECT_EQ(5, linenoiseHistorySize());
+
+  // clean up the user
+  shell.process_line("\\sql drop user foo@bar;");
 }
 
 TEST_F(Shell_history, history_ignore_wildcard_questionmark) {
@@ -378,6 +381,7 @@ TEST_F(Shell_history, history_ignore_wildcard_questionmark) {
   EXPECT_EQ(1, linenoiseHistorySize());
 
   shell.process_line(to_scripting);
+  shell.process_line("shell.options['defaultMode'] = 'js'");
   shell.process_line(
       "shell.options['history.sql.ignorePattern'] = '?? ??;:?\?'");
   shell.process_line("\\sql");
@@ -420,8 +424,10 @@ TEST_F(Shell_history, history_set_option) {
 }
 
 TEST_F(Shell_history, history_ignore_pattern_js) {
+  char *args[] = {const_cast<char *>("ut"), const_cast<char *>("--js"),
+                  nullptr};
   mysqlsh::Command_line_shell shell(
-      std::make_shared<Shell_options>(0, nullptr, _options_file));
+      std::make_shared<Shell_options>(2, args, _options_file));
 
   shell.process_line("shell.options['history.sql.ignorePattern'] = '*SELECT*'");
   shell.process_line("// SELECT");
@@ -456,8 +462,10 @@ TEST_F(Shell_history, history_linenoise) {
   // TS_HM#1 only commands interactively typed by the user in the shell prompt
   // are saved to history file: ~/.mysqlsh/history file
 
+  char *args[] = {const_cast<char *>("ut"), const_cast<char *>("--js"),
+                  nullptr};
   mysqlsh::Command_line_shell shell(
-      std::make_shared<Shell_options>(0, nullptr, _options_file));
+      std::make_shared<Shell_options>(2, args, _options_file));
   const std::string hist_file = shell.history_file();
   shcore::delete_file(hist_file);
 
@@ -613,8 +621,10 @@ TEST_F(Shell_history, check_help_shows_history) {
   // My preference is a global one but I'm not the one to maintain the UTs so
   // I'll just do something and let the owners of the UTs decide.
 
+  char *args[] = {const_cast<char *>("ut"), const_cast<char *>("--js"),
+                  nullptr};
   mysqlsh::Command_line_shell shell(
-      std::make_shared<Shell_options>(0, nullptr, _options_file));
+      std::make_shared<Shell_options>(2, args, _options_file));
 
   {
     // Expecting the Shell mention \history in \help
@@ -629,8 +639,10 @@ TEST_F(Shell_history, check_help_shows_history) {
 }
 
 TEST_F(Shell_history, history_autosave_int) {
+  char *args[] = {const_cast<char *>("ut"), const_cast<char *>("--js"),
+                  nullptr};
   mysqlsh::Command_line_shell shell(
-      std::make_shared<Shell_options>(0, nullptr, _options_file));
+      std::make_shared<Shell_options>(2, args, _options_file));
   shcore::delete_file(shell.history_file());
 
   {
@@ -650,7 +662,7 @@ TEST_F(Shell_history, history_autosave_int) {
   }
 }
 
-#ifdef HAVE_JS
+#ifdef HAVE_V8
 TEST_F(Shell_history, check_history_source_js) {
   // WL#10446 says \source shall no add entries to the history
   // Only history entry shall the \source itself
@@ -862,8 +874,11 @@ TEST_F(Shell_history, check_history_overflow_del) {
   // overflows, entries are dropped and renumbering might take place.
 
   {
+    char *args[] = {const_cast<char *>("ut"), const_cast<char *>("--js"),
+                    nullptr};
     mysqlsh::Command_line_shell shell(
-        std::make_shared<Shell_options>(0, nullptr, _options_file));
+        std::make_shared<Shell_options>(2, args, _options_file));
+
     shell._history.set_limit(3);
 
     EXPECT_NO_THROW(shell.load_state());
@@ -1060,8 +1075,10 @@ TEST_F(Shell_history, history_sizes) {
   // This test shall cover internal list management (grow, shrink, overflow).
   // No crash is good enough.
   // See also src/mysqlsh/history.cc|h
+  char *args[] = {const_cast<char *>("ut"), const_cast<char *>("--js"),
+                  nullptr};
   mysqlsh::Command_line_shell shell(
-      std::make_shared<Shell_options>(0, nullptr, _options_file));
+      std::make_shared<Shell_options>(2, args, _options_file));
 
   enable_capture();
 
@@ -1156,8 +1173,10 @@ TEST_F(Shell_history, history_source_history) {
   // using \source. \source shall not add any executed commands to history
   // but preserve the history state from after save.
 
+  char *args[] = {const_cast<char *>("ut"), const_cast<char *>("--js"),
+                  nullptr};
   mysqlsh::Command_line_shell shell(
-      std::make_shared<Shell_options>(0, nullptr, _options_file));
+      std::make_shared<Shell_options>(2, args, _options_file));
 
   enable_capture();
 
@@ -1183,8 +1202,10 @@ TEST_F(Shell_history, history_source_history) {
 }
 
 TEST_F(Shell_history, history_del_range) {
+  char *args[] = {const_cast<char *>("ut"), const_cast<char *>("--js"),
+                  nullptr};
   mysqlsh::Command_line_shell shell(
-      std::make_shared<Shell_options>(0, nullptr, _options_file));
+      std::make_shared<Shell_options>(2, args, _options_file));
 
   enable_capture();
 
@@ -1233,8 +1254,10 @@ TEST_F(Shell_history, history_entry_number_reset) {
   // Numbering shall only be reset when Shell is restarted
   // or when \\history clear is called
 
+  char *args[] = {const_cast<char *>("ut"), const_cast<char *>("--js"),
+                  nullptr};
   mysqlsh::Command_line_shell shell(
-      std::make_shared<Shell_options>(0, nullptr, _options_file));
+      std::make_shared<Shell_options>(2, args, _options_file));
 
   enable_capture();
 
@@ -1457,8 +1480,11 @@ TEST_F(Shell_history, history_delete_range) {
 }
 
 TEST_F(Shell_history, history_numbering) {
+  char *args[] = {const_cast<char *>("ut"), const_cast<char *>("--js"),
+                  nullptr};
   mysqlsh::Command_line_shell shell(
-      std::make_shared<Shell_options>(0, nullptr, _options_file));
+      std::make_shared<Shell_options>(2, args, _options_file));
+
   enable_capture();
   using strv = std::vector<std::string>;
 
@@ -1659,7 +1685,7 @@ TEST_F(Shell_history, migrate_old_history) {
   EXPECT_TRUE(
       shcore::is_file(shell.history_file(shcore::IShell_core::Mode::SQL)));
   shcore::delete_file(shell.history_file(shcore::IShell_core::Mode::SQL));
-#ifdef HAVE_JS
+#ifdef HAVE_V8
   shell.process_line("\\js\n");
   EXPECT_EQ(history_size, linenoiseHistorySize());
   EXPECT_TRUE(shcore::is_file(
@@ -1677,8 +1703,10 @@ TEST_F(Shell_history, migrate_old_history) {
 }
 
 TEST_F(Shell_history, get_entry) {
+  char *args[] = {const_cast<char *>("ut"), const_cast<char *>("--js"),
+                  nullptr};
   mysqlsh::Command_line_shell shell(
-      std::make_shared<Shell_options>(0, nullptr, _options_file));
+      std::make_shared<Shell_options>(2, args, _options_file));
 
   const auto &history = shell._history;
 
